@@ -26,14 +26,20 @@ class Common:
         self.now = datetime.now()
         self.today = datetime.now().date()
 
+    def running_in_airflow(self):
+        return any(k.startswith("AIRFLOW_") for k in os.environ.keys())
 
     def log_func(self, bot_token, chat_ids,message, value):
         try:
             print(message)
-            log_file_path = "/app/log.txt"
-            os.makedirs(os.path.dirname(log_file_path), exist_ok=True)
+            if self.running_in_airflow():
+                log_dir = "/opt/airflow/logs"
+            else:
+                log_dir = "/app/logs"
+            os.makedirs(log_dir, exist_ok=True)
+            log_file_path = os.path.join(log_dir, "log.txt")
             if value >= self.value:
-                with open(log_file_path, "a") as log_file:
+                with open(log_file_path, "a", encoding="utf-8") as log_file:
                     log_file.write(message + "\n\n")
             self.send_logs_clear(bot_token, chat_ids, message)
         except Exception as e:
@@ -41,7 +47,10 @@ class Common:
 
     def send_logs_clear(self,bot_token, chat_ids, message):
         try:
-            log_file_path = "/app/log.txt"
+            if self.running_in_airflow():
+                log_file_path = "/opt/airflow/log.txt"
+            else:
+                log_file_path = "/app/logs/log.txt"
             if not os.path.exists(log_file_path):
                 print("Файл лога не существует.")
             with open(log_file_path, "r") as log_file:
@@ -58,7 +67,10 @@ class Common:
 
     def send_logs_clear_anyway(self,bot_token, chat_ids):
         try:
-            log_file_path = "/app/log.txt"
+            if self.running_in_airflow():
+                log_file_path = "/opt/airflow/log.txt"
+            else:
+                log_file_path = "/app/logs/log.txt"
             if not os.path.exists(log_file_path):
                 print("Файл лога не существует.")
             with open(log_file_path, "r") as log_file:
